# Android tools for Python 3

A support library to work with Android devices and apps.
Allows Python apps and scripts to access the host commands to interact
with connected Android devices through `adb` and `fastboot`.
Android apps are handled through `aapt` and `adb`.

This library wraps around the well-known
[Android SDK Platform Tools](https://developer.android.com/studio/releases/platform-tools)
and works together with them.

## Installation

The _Android tools for Python 3_ library can be installed directly from
the Git repository:

    # Install the latest native Python RSA crypto library
    $ pip install rsa~=4.0
    # Install the latest library version
    $ pip install --process-dependency-links \
    'git+https://code.fairphone.com/gerrit/vendor/fairphone/tools#subdirectory=python-libs/android-tools&egg=android-tools'

It requires:
* Python 3.6
* The Android SDK Platform Tools 24 (Android app support)
* The [libusb-1.0](https://libusb.info/) library (Android devices support)
* One of the Python [RSA library](https://stuvel.eu/rsa) or the (compiled)
  [M2Crypto library](https://gitlab.com/m2crypto/m2crypto)

## Development

This library belongs to the
[Fairphone Android tools](https://code.fairphone.com/gerrit/gitweb?p=vendor/fairphone/tools.git)
project. Refer to its documentation for more information.

### Versioning

The intersection of
[PEP 440](https://www.python.org/dev/peps/pep-0440/) and
[Semantic Versioning 2.00](https://semver.org/spec/v2.0.0.html) defines
the simple versioning scheme: "major.minor[.patch]".

## License

The project is made available under the terms of the Apache 2.0 license.
See [LICENSE](LICENSE) for details.

## Release notes

### 0.1

Initial release:

* Introduce support class for Android apps (`android_tools.App`);
* Introduce support class for Android devices (`android_tools.Device`);
* Introduce wrappers for `aapt`, `adb`, and `fastboot` that must be
  installed on the host.
